@@ -34,7 +34,7 @@
 #'               the treatment Wi or the outcome Yi.
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' # Train a causal forest.
 #' n <- 50
 #' p <- 10
@@ -56,7 +56,7 @@
 #' average_treatment_effect(c.forest, target.sample = "treated")
 #'
 #' # Estimate the conditional average treatment effect on samples with positive X[,1].
-#' average_treatment_effect(c.forest, target.sample = "all", X[, 1] > 0)
+#' average_treatment_effect(c.forest, target.sample = "all", subset = X[, 1] > 0)
 #' }
 #'
 #' @return An estimate of the average treatment effect, along with standard error.
@@ -75,7 +75,7 @@ average_treatment_effect <- function(forest,
     stop("Average effect estimation only implemented for causal_forest")
   }
 
-  if (cluster.se & method == "TMLE") {
+  if (cluster.se && method == "TMLE") {
     stop("TMLE has not yet been implemented with clustered observations.")
   }
 
@@ -83,7 +83,7 @@ average_treatment_effect <- function(forest,
     subset <- 1:length(forest$Y.hat)
   }
 
-  if (class(subset) == "logical" & length(subset) == length(forest$Y.hat)) {
+  if (class(subset) == "logical" && length(subset) == length(forest$Y.hat)) {
     subset <- which(subset)
   }
 
