@@ -56,7 +56,6 @@ Rcpp::List regression_train(Rcpp::NumericMatrix train_matrix,
   if(use_sample_weights) {
       data->set_weight_index(sample_weight_index - 1);
   }
-  data->sort();
 
   ForestOptions options(num_trees, ci_group_size, sample_fraction, mtry, min_node_size, honesty,
       honesty_fraction, honesty_prune_leaves, alpha, imbalance_penalty, num_threads, seed, clusters, samples_per_cluster);
@@ -116,8 +115,8 @@ Rcpp::List ll_regression_train(Rcpp::NumericMatrix train_matrix,
                             Eigen::SparseMatrix<double> sparse_train_matrix,
                             size_t outcome_index,
                             size_t sample_weight_index,
-                            double split_lambda,
-                            bool weight_penalty,
+                            double ll_split_lambda,
+                            bool ll_split_weight_penalty,
                             std::vector<size_t> ll_split_variables,
                             size_t ll_split_cutoff,
                             std::vector<double> overall_beta,
@@ -136,7 +135,7 @@ Rcpp::List ll_regression_train(Rcpp::NumericMatrix train_matrix,
                             unsigned int samples_per_cluster,
                             unsigned int num_threads,
                             unsigned int seed) {
-  ForestTrainer trainer = ll_regression_trainer(split_lambda, weight_penalty, overall_beta,
+  ForestTrainer trainer = ll_regression_trainer(ll_split_lambda, ll_split_weight_penalty, overall_beta,
                                                ll_split_cutoff, ll_split_variables);
 
   std::unique_ptr<Data> data = RcppUtilities::convert_data(train_matrix, sparse_train_matrix);
@@ -144,7 +143,6 @@ Rcpp::List ll_regression_train(Rcpp::NumericMatrix train_matrix,
   if(use_sample_weights) {
     data->set_weight_index(sample_weight_index - 1);
   }
-  data->sort();
 
   ForestOptions options(num_trees, ci_group_size, sample_fraction, mtry, min_node_size, honesty,
                         honesty_fraction, honesty_prune_leaves, alpha, imbalance_penalty, num_threads, seed, clusters, samples_per_cluster);
@@ -155,14 +153,14 @@ Rcpp::List ll_regression_train(Rcpp::NumericMatrix train_matrix,
 }
 
 // [[Rcpp::export]]
-Rcpp::List ll_regression_predict(Rcpp::List forest,
+Rcpp::List ll_regression_predict(Rcpp::List forest_object,
                                 Rcpp::NumericMatrix train_matrix,
                                 Eigen::SparseMatrix<double> sparse_train_matrix,
                                 size_t outcome_index,
                                 Rcpp::NumericMatrix test_matrix,
                                 Eigen::SparseMatrix<double> sparse_test_matrix,
-                                std::vector<double> lambdas,
-                                bool weight_penalty,
+                                std::vector<double> ll_lambda,
+                                bool ll_weight_penalty,
                                 std::vector<size_t> linear_correction_variables,
                                 unsigned int num_threads,
                                 bool estimate_variance) {
@@ -170,10 +168,10 @@ Rcpp::List ll_regression_predict(Rcpp::List forest,
   train_data->set_outcome_index(outcome_index - 1);
   std::unique_ptr<Data> data = RcppUtilities::convert_data(test_matrix, sparse_test_matrix);
 
-  Forest deserialized_forest = RcppUtilities::deserialize_forest(forest);
+  Forest deserialized_forest = RcppUtilities::deserialize_forest(forest_object);
 
   ForestPredictor predictor = ll_regression_predictor(num_threads,
-      lambdas, weight_penalty, linear_correction_variables);
+      ll_lambda, ll_weight_penalty, linear_correction_variables);
   std::vector<Prediction> predictions = predictor.predict(deserialized_forest, *train_data, *data, estimate_variance);
   Rcpp::List result = RcppUtilities::create_prediction_object(predictions);
 
@@ -181,22 +179,22 @@ Rcpp::List ll_regression_predict(Rcpp::List forest,
 }
 
 // [[Rcpp::export]]
-Rcpp::List ll_regression_predict_oob(Rcpp::List forest,
+Rcpp::List ll_regression_predict_oob(Rcpp::List forest_object,
                                     Rcpp::NumericMatrix train_matrix,
                                     Eigen::SparseMatrix<double> sparse_train_matrix,
                                     size_t outcome_index,
-                                    std::vector<double> lambdas,
-                                    bool weight_penalty,
+                                    std::vector<double> ll_lambda,
+                                    bool ll_weight_penalty,
                                     std::vector<size_t> linear_correction_variables,
                                     unsigned int num_threads,
                                     bool estimate_variance) {
   std::unique_ptr<Data> data = RcppUtilities::convert_data(train_matrix, sparse_train_matrix);
   data->set_outcome_index(outcome_index - 1);
 
-  Forest deserialized_forest = RcppUtilities::deserialize_forest(forest);
+  Forest deserialized_forest = RcppUtilities::deserialize_forest(forest_object);
 
   ForestPredictor predictor = ll_regression_predictor(num_threads,
-      lambdas, weight_penalty, linear_correction_variables);
+      ll_lambda, ll_weight_penalty, linear_correction_variables);
   std::vector<Prediction> predictions = predictor.predict_oob(deserialized_forest, *data, estimate_variance);
   Rcpp::List result = RcppUtilities::create_prediction_object(predictions);
 
