@@ -15,12 +15,14 @@
   along with grf. If not, see <http://www.gnu.org/licenses/>.
  #-------------------------------------------------------------------------------*/
 
-#ifndef GRF_VARIABLEIMPORTANCECOMPUTER_H
-#define GRF_VARIABLEIMPORTANCECOMPUTER_H
+#ifndef GRF_SPLITFREQUENCYCOMPUTER_H
+#define GRF_SPLITFREQUENCYCOMPUTER_H
 
 
 #include "forest/Forest.h"
 
+namespace grf {
+
 /**
  * Computes a matrix of split depth by variable ID, where each value is
  * the number of times the variable was split on at that depth.
@@ -31,8 +33,9 @@
 class SplitFrequencyComputer {
 public:
   std::vector<std::vector<size_t>> compute(const Forest& forest,
-                                           size_t max_depth);
+                                           size_t max_depth) const;
 };
 
+} // namespace grf
 
-#endif //GRF_VARIABLEIMPORTANCECOMPUTER_H
+#endif //GRF_SPLITFREQUENCYCOMPUTER_H
